==> react-form-builder-4.45.0.tgz: package/lib/MultiButton/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo } from 'react';
import PropTypes from 'prop-types';
import AtomTag from '@s-ui/react-atom-tag';
import MoleculeField from '@s-ui/react-molecule-field';
import { field, createComponentMemo } from '../prop-types';
import { createElement as _createElement } from "react";
import { jsx as _jsx } from "react/jsx-runtime";

var MultiButton = function MultiButton(_ref) {
  var alerts = _ref.alerts,
      errors = _ref.errors,
      multiButton = _ref.multiButton,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      renderer = _ref.renderer,
      tabIndex = _ref.tabIndex;
  var errorMessages = errors[multiButton.id];
  var alertMessages = alerts[multiButton.id];

  var onClickCallback = function onClickCallback(_ref2) {
    var _multiButton$value;

    var value = _ref2.value,
        checked = _ref2.checked;
    var newValue = checked ? (_multiButton$value = multiButton.value) == null ? void 0 : _multiButton$value.filter(function (id) {
      return id !== value;
    }) : [].concat(multiButton.value || [], [value]);
    return onChange(multiButton.id, newValue);
  };

  var onFocusCallback = function onFocusCallback() {
    return onFocus(multiButton.id);
  };

  var onBlurCallback = function onBlurCallback() {
    return onBlur(multiButton.id);
  };

  var multiButtonProps = _extends({
    id: multiButton.id,
    label: multiButton.label,
    onBlur: onBlurCallback,
    onFocus: onFocusCallback,
    tabIndex: tabIndex,
    value: multiButton.value
  }, multiButton.disabled && {
    disabled: true
  }, multiButton.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  if (multiButtonProps.hidden) return null;
  var rendererResponse = renderer({
    id: multiButton.id,
    innerProps: multiButtonProps
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/_jsx("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-MultiButton sui-FormBuilder-" + (multiButtonProps.id || tabIndex),
    children: /*#__PURE__*/_jsx(MoleculeField, _extends({}, multiButtonProps, {
      children: /*#__PURE__*/_jsx("div", {
        className: "sui-FormBuilder-MultiButton-itemList",
        children: multiButton.datalist.map(function (_ref3) {
          var _multiButton$value2;

          var value = _ref3.value,
              text = _ref3.text;
          var checked = (_multiButton$value2 = multiButton.value) == null ? void 0 : _multiButton$value2.some(function (id) {
            return id === value;
          });
          return /*#__PURE__*/_createElement(AtomTag, _extends({}, multiButtonProps, rendererResponse, {
            key: value,
            onClick: function onClick() {
              return onClickCallback({
                value: value,
                checked: checked
              });
            },
            design: checked ? 'solid' : 'outline',
            label: text,
            id: value
          }));
        })
      })
    }))
  });
};

MultiButton.displayName = 'MultiButton';
export default /*#__PURE__*/memo(MultiButton, createComponentMemo('multiButton'));

==> react-form-builder-5.11.0.tgz: package/lib/MultiButton/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo } from 'react';
import PropTypes from 'prop-types';
import AtomTag from '@s-ui/react-atom-tag';
import MoleculeField from '@s-ui/react-molecule-field';
import { createComponentMemo, field } from '../prop-types';
import { createElement as _createElement } from "react";
import { jsx as _jsx } from "react/jsx-runtime";

var MultiButton = function MultiButton(_ref) {
  var alerts = _ref.alerts,
      errors = _ref.errors,
      multiButton = _ref.multiButton,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      renderer = _ref.renderer,
      tabIndex = _ref.tabIndex;
  var errorMessages = errors[multiButton.id];
  var alertMessages = alerts[multiButton.id];

  var onClickCallback = function onClickCallback(_ref2) {
    var _multiButton$value;

    var value = _ref2.value,
        checked = _ref2.checked;
    var newValue = checked ? (_multiButton$value = multiButton.value) == null ? void 0 : _multiButton$value.filter(function (id) {
      return id !== value;
    }) : [].concat(multiButton.value || [], [value]);
    return onChange(multiButton.id, newValue);
  };

  var onFocusCallback = function onFocusCallback() {
    return onFocus(multiButton.id);
  };

  var onBlurCallback = function onBlurCallback() {
    return onBlur(multiButton.id);
  };

  var multiButtonProps = _extends({
    id: multiButton.id,
    label: multiButton.label,
    onBlur: onBlurCallback,
    onFocus: onFocusCallback,
    tabIndex: tabIndex,
    value: multiButton.value
  }, multiButton.disabled && {
    disabled: true
  }, multiButton.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  if (multiButtonProps.hidden) return null;
  var rendererResponse = renderer({
    id: multiButton.id,
    innerProps: multiButtonProps
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/_jsx("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-MultiButton sui-FormBuilder-" + (multiButtonProps.id || tabIndex),
    children: /*#__PURE__*/_jsx(MoleculeField, _extends({}, multiButtonProps, {
      children: /*#__PURE__*/_jsx("div", {
        className: "sui-FormBuilder-MultiButton-itemList",
        children: multiButton.datalist.map(function (_ref3) {
          var _multiButton$value2;

          var value = _ref3.value,
              text = _ref3.text;
          var checked = (_multiButton$value2 = multiButton.value) == null ? void 0 : _multiButton$value2.some(function (id) {
            return id === value;
          });
          return /*#__PURE__*/_createElement(AtomTag, _extends({}, multiButtonProps, rendererResponse, {
            key: value,
            onClick: function onClick() {
              return onClickCallback({
                value: value,
                checked: checked
              });
            },
            design: checked ? 'solid' : 'outline',
            label: text,
            id: value
          }));
        })
      })
    }))
  });
};

MultiButton.displayName = 'MultiButton';
export default /*#__PURE__*/memo(MultiButton, createComponentMemo('multiButton'));
